Files
rocm-systems/projects/hip/tests/src/runtimeApi/synchronization/memcpyInt.device.cpp
T
Maneesh Gupta 4f42ee762d Apply .clangformat to all repo source files
Change-Id: I7e79c6058f0303f9a98911e3b7dd2e8596079344


[ROCm/hip commit: 1ba06f63c4]
2018-03-12 11:29:03 +05:30

12 строки
370 B
C++

#include <hip/hip_runtime.h>
extern "C" __global__ void memcpyIntKernel(hipLaunchParm lp, int* dst, const int* src,
size_t numElements) {
int gid = (blockIdx.x * blockDim.x + threadIdx.x);
int stride = blockDim.x * gridDim.x;
for (size_t i = gid; i < numElements; i += stride) {
dst[i] = src[i];
}
};